﻿using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace WpfApplication5
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private RotationProjection rotateProjection;

        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.DecimalDegree;
            rotateProjection = new RotationProjection();
            Map1.CurrentExtent = rotateProjection.GetUpdatedExtent(new RectangleShape(-180.0, 83.0, 180.0, -90.0));

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"MapData\\Countries02.shp");
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.FeatureSource.Projection = rotateProjection;

            LayerOverlay worldOverlay = new LayerOverlay();
            worldOverlay.TileType = TileType.SingleTile;
            worldOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)));
            worldOverlay.Layers.Add("WorldLayer", worldLayer);
            Map1.Overlays.Add("WorldOverlay", worldOverlay);

            Map1.Refresh();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            rotateProjection.Angle -= 20;
            Map1.CurrentExtent = rotateProjection.GetUpdatedExtent(Map1.CurrentExtent);
            Map1.Overlays["WorldOverlay"].Refresh();
        }
    }
}
